.. _authentication_module:

:mod:`pyramid.authentication`
--------------------------------

Authentication Policies
~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: pyramid.authentication

  .. autoclass:: AuthTktAuthenticationPolicy

  .. autoclass:: RepozeWho1AuthenticationPolicy

  .. autoclass:: RemoteUserAuthenticationPolicy

  .. autoclass:: SessionAuthenticationPolicy

Helper Classes
~~~~~~~~~~~~~~

  .. autoclass:: AuthTktCookieHelper
     :members:



